from distutils.core import setup

setup(
    name         = 'fengcoco_nester',
    version      = '1.3.0',
    author       = 'fengdanfeng',
    py_modules   = ['fengcoco_nester'],
    author_email = '811850534@qq.com',
    url          = 'http://www.headfirstlabs.com',
    description  = 'A simple printer of nested lists',
)
